@@ -6,66 +6,62 @@
 
     Models for the participant app.
 
-    :copyright: 2011, 2012 by OpenSlides team, see AUTHORS.
+    :copyright: 2011–2013 by OpenSlides team, see AUTHORS.
     :license: GNU GPL, see LICENSE for more details.
 """
 
-from django.contrib.auth.models import User as DjangoUser, Group as DjangoGroup
+from django.contrib.auth.models import User as DjangoUser, Group as DjangoGroup, Permission
+from django.contrib.contenttypes.models import ContentType
 from django.db import models
 from django.db.models import signals
 from django.dispatch import receiver
-from django.utils.translation import ugettext_lazy as _, ugettext_noop
+from django.utils.translation import ugettext_lazy, ugettext_noop
 
 from openslides.utils.person import PersonMixin, Person
 from openslides.utils.person.signals import receive_persons
-
-from openslides.config.models import config
-from openslides.config.signals import default_config_value
-
+from openslides.config.api import config
 from openslides.projector.api import register_slidemodel
 from openslides.projector.projector import SlideMixin
 
 
-class User(DjangoUser, PersonMixin, Person, SlideMixin):
+class User(PersonMixin, Person, SlideMixin, DjangoUser):
     prefix = 'user'  # This is for the slides
     person_prefix = 'user'
     GENDER_CHOICES = (
-        ('male', _('Male')),
-        ('female', _('Female')),
-    )
-    TYPE_CHOICES = (
-        ('delegate', _('Delegate')),
-        ('observer', _('Observer')),
-        ('staff', _('Staff')),
-        ('guest', _('Guest')),
+        ('male', ugettext_lazy('Male')),
+        ('female', ugettext_lazy('Female')),
     )
 
     django_user = models.OneToOneField(DjangoUser, editable=False, parent_link=True)
     structure_level = models.CharField(
-        max_length=100, blank=True, default='', verbose_name=_("Structure level"),
-        help_text=_('Will be shown after the name.'))
+        max_length=255, blank=True, default='', verbose_name=ugettext_lazy("Structure level"),
+        help_text=ugettext_lazy('Will be shown after the name.'))
+    title = models.CharField(
+        max_length=50, blank=True, default='', verbose_name=ugettext_lazy("Title"),
+        help_text=ugettext_lazy('Will be shown before the name.'))
     gender = models.CharField(
         max_length=50, choices=GENDER_CHOICES, blank=True,
-        verbose_name=_("Gender"), help_text=_('Only for filtering the participant list.'))
-    type = models.CharField(
-        max_length=100, choices=TYPE_CHOICES, blank=True,
-        verbose_name=_("Typ"), help_text=_('Only for filtering the participant list.'))
+        verbose_name=ugettext_lazy("Gender"), help_text=ugettext_lazy('Only for filtering the participant list.'))
     committee = models.CharField(
-        max_length=100, blank=True, default='', verbose_name=_("Committee"),
-        help_text=_('Only for filtering the participant list.'))
+        max_length=255, blank=True, default='', verbose_name=ugettext_lazy("Committee"),
+        help_text=ugettext_lazy('Only for filtering the participant list.'))
     about_me = models.TextField(
-        blank=True, default='', verbose_name=_('About me'),
-        help_text=_('Your profile text'))
+        blank=True, default='', verbose_name=ugettext_lazy('About me'),
+        help_text=ugettext_lazy('Your profile text'))
     comment = models.TextField(
-        blank=True, default='', verbose_name=_('Comment'),
-        help_text=_('Only for notes.'))
+        blank=True, default='', verbose_name=ugettext_lazy('Comment'),
+        help_text=ugettext_lazy('Only for notes.'))
     default_password = models.CharField(
         max_length=100, blank=True, default='',
-        verbose_name=_("Default password"))
+        verbose_name=ugettext_lazy("Default password"))
 
     @property
     def clean_name(self):
-        return self.get_full_name() or self.username
+        if self.title:
+            name = "%s %s" % (self.title, self.get_full_name())
+        else:
+            name = self.get_full_name()
+        return name or self.username
 
     def get_name_suffix(self):
         return self.structure_level
@@ -91,16 +87,16 @@ class User(DjangoUser, PersonMixin, Person, SlideMixin):
         return self.last_name.lower()
 
     @models.permalink
-    def get_absolute_url(self, link='view'):
+    def get_absolute_url(self, link='detail'):
         """
         Return the URL to this user.
 
         link can be:
-        * view
+        * detail
         * edit
         * delete
         """
-        if link == 'view':
+        if link == 'detail' or link == 'view':
             return ('user_view', [str(self.id)])
         if link == 'edit':
             return ('user_edit', [str(self.id)])
@@ -115,9 +111,8 @@ class User(DjangoUser, PersonMixin, Person, SlideMixin):
     class Meta:
         # Rename permissions
         permissions = (
-            ('can_see_participant', ugettext_noop("Can see participant")),
-            ('can_manage_participant',
-                ugettext_noop("Can manage participant")),
+            ('can_see_participant', ugettext_noop('Can see participants')),  # TODO: Add plural s to the codestring
+            ('can_manage_participant', ugettext_noop('Can manage participants')),  # TODO: Add plural s to the codestring
         )
         ordering = ('last_name',)
 
@@ -133,18 +128,18 @@ class User(DjangoUser, PersonMixin, Person, SlideMixin):
 register_slidemodel(User)
 
 
-class Group(DjangoGroup, PersonMixin, Person, SlideMixin):
+class Group(PersonMixin, Person, SlideMixin, DjangoGroup):
     prefix = 'group'  # This is for the slides
     person_prefix = 'group'
 
     django_group = models.OneToOneField(DjangoGroup, editable=False, parent_link=True)
     group_as_person = models.BooleanField(
-        default=False, verbose_name=_("Use this group as participant"),
-        help_text=_('For example as submitter of a motion.'))
-    description = models.TextField(blank=True, verbose_name=_("Description"))
+        default=False, verbose_name=ugettext_lazy("Use this group as participant"),
+        help_text=ugettext_lazy('For example as submitter of a motion.'))
+    description = models.TextField(blank=True, verbose_name=ugettext_lazy("Description"))
 
     @models.permalink
-    def get_absolute_url(self, link='view'):
+    def get_absolute_url(self, link='detail'):
         """
         Return the URL to this user group.
 
@@ -153,7 +148,7 @@ class Group(DjangoGroup, PersonMixin, Person, SlideMixin):
         * edit
         * delete
         """
-        if link == 'view':
+        if link == 'detail' or link == 'view':
             return ('user_group_view', [str(self.id)])
         if link == 'edit':
             return ('user_group_edit', [str(self.id)])
@@ -226,19 +221,6 @@ def receive_persons(sender, **kwargs):
         id_filter=kwargs['id_filter'])
 
 
-@receiver(default_config_value, dispatch_uid="participant_default_config")
-def default_config(sender, key, **kwargs):
-    """
-    Default values for the participant app.
-    """
-    # TODO: Rename config-vars
-    return {
-        'participant_pdf_system_url': 'http://example.com:8000',
-        'participant_pdf_welcometext': _('Welcome to OpenSlides!'),
-        'participant_sort_users_by_first_name': False,
-    }.get(key)
-
-
 @receiver(signals.post_save, sender=DjangoUser)
 def djangouser_post_save(sender, instance, signal, *args, **kwargs):
     try:
@@ -257,9 +239,19 @@ def djangogroup_post_save(sender, instance, signal, *args, **kwargs):
 
 @receiver(signals.post_save, sender=User)
 def user_post_save(sender, instance, *args, **kwargs):
-    from openslides.participant.api import get_or_create_registered_group
     if not kwargs['created']:
         return
-    registered = get_or_create_registered_group()
+    from openslides.participant.api import get_registered_group  # TODO: Test, if global import is possible
+    registered = get_registered_group()
     instance.groups.add(registered)
     instance.save()
+
+
+def get_protected_perm():
+    """
+    Returns the permission to manage participants. This function is a helper
+    function used to protect manager users from locking out themselves.
+    """
+    return Permission.objects.get(
+        content_type=ContentType.objects.get(app_label='participant', model='user'),
+        codename='can_manage_participant')
