@@ -15,7 +15,7 @@ from django.core.cache import cache
 from django.utils.datastructures import SortedDict
 from django.utils.importlib import import_module
 
-from openslides.config.models import config
+from openslides.config.api import config
 from openslides.projector.projector import SLIDE, Slide
 
 
@@ -89,10 +89,9 @@ def set_active_slide(sid, argument=None):
 
 
 def clear_projector_cache():
-    for language, __ in settings.LANGUAGES:
-        cache.delete('projector_content_' + language)
-        cache.delete('projector_scrollcontent_' + language)
-        cache.delete('projector_data_' + language)
+    cache.delete('projector_content')
+    cache.delete('projector_scrollcontent')
+    cache.delete('projector_data')
 
 
 def register_slidemodel(model, model_name=None, control_template=None, weight=0):
@@ -121,29 +120,14 @@ def register_slidefunc(key, func, control_template=None, weight=0, name=''):
                        name=name,)
 
 
-def projector_message_set(message, sid=None):
-    """
-    Set the overlay-message.
-    if sid is set, only show the message on the sid-slide.
-    """
-    from models import ProjectorOverlay
-    config['projector_message'] = message
-    try:
-        overlay = ProjectorOverlay.objects.get(def_name='Message')
-    except ProjectorOverlay.DoesNotExist:
-        overlay = ProjectorOverlay(def_name='Message', active=False)
-    overlay.sid = sid
-    overlay.save()
-
-
-def projector_message_delete():
-    """
-    Delete the overlay-message.
-    """
-    config['projector_message'] = ''
-
-
 def get_all_widgets(request, session=False):
+    """
+    Collects the widgets from all apps and returns the Widget objects as sorted
+    dictionary.
+
+    The session flag decides whether to return only the widgets which are
+    active, that means that they are mentioned in the session.
+    """
     widgets = SortedDict()
     session_widgets = request.session.get('widgets', {})
     for app in settings.INSTALLED_APPS:
